@@ -17,8 +17,8 @@ class GraspManager(ActivityBase):
         robot_col_manager,
         obstacles_col_manager,
         mesh_path,
-        release_distance = 0.01,
         retreat_distance = 0.1,
+        release_distance = 0.01,
         **gripper_configures
     ):
         super().__init__(
@@ -28,11 +28,11 @@ class GraspManager(ActivityBase):
             mesh_path,
             **gripper_configures)
 
-        self.release_distance = release_distance
         self.retreat_distance = retreat_distance
+        self.release_distance = release_distance
         self.tcp_pose = np.eye(4)
         self.result_obj_pose = np.eye(4)
-        self.contact_point = None
+        self.contact_points = None
 
     def get_grasp_waypoints(
         self,
@@ -44,8 +44,7 @@ class GraspManager(ActivityBase):
     ):
         waypoints = OrderedDict()
 
-        grasp_pose, _, _, _= self.get_grasp_pose(obj_mesh, obj_pose, limit_angle, num_grasp, n_trials)
-        
+        grasp_pose = self.get_grasp_pose(obj_mesh, obj_pose, limit_angle, num_grasp, n_trials)    
         waypoints["pre_grasp"] = self.pre_grasp_pose
         waypoints["grasp"] = grasp_pose
         waypoints["post_grasp"] =self.post_grasp_pose
@@ -60,12 +59,9 @@ class GraspManager(ActivityBase):
         num_grasp=1,
         n_trials=1,
     ):
-        grasp_poses = list(self.generate_grasps(obj_mesh, obj_pose, limit_angle, num_grasp, n_trials))
-        grasp_pose, tcp_pose, contact_point, normal = self.filter_grasps(grasp_poses)
-        self.tcp_pose = tcp_pose
-        self.contact_point = contact_point
-        
-        return grasp_pose, tcp_pose, contact_point, normal
+        grasp_poses = self.generate_grasps(obj_mesh, obj_pose, limit_angle, num_grasp, n_trials)
+        grasp_pose = self.filter_grasps(grasp_poses)     
+        return grasp_pose
 
     def get_pre_grasp_pose(self, grasp_pose):
         pre_grasp_pose = np.eye(4)
@@ -77,24 +73,26 @@ class GraspManager(ActivityBase):
         self,
         obj_mesh,
         obj_pose,
-        limit_angle,
+        limit_angle=0.05, #radian
         num_grasp=1,
         n_trials=1
     ):
         cnt = 0
         while cnt < num_grasp * n_trials:
             tcp_poses = self.generate_tcp_poses(obj_mesh, obj_pose, limit_angle, n_trials)
-            for tcp_pose, contact_point, normal in tcp_poses:
-                eef_pose = self.get_eef_h_mat_from_tcp(tcp_pose)
+            for tcp_pose, contact_points, _ in tcp_poses:
                 gripper_transformed = self.get_gripper_transformed(tcp_pose)
 
                 if self.collision_free(gripper_transformed, only_gripper=True):
-                    yield (eef_pose, tcp_pose, contact_point, normal)
-            cnt += 1
-
+                    self.tcp_pose = tcp_pose
+                    self.contact_points = contact_points
+                    eef_pose = self.get_eef_h_mat_from_tcp(tcp_pose)
+                    cnt += 1
+                    yield (eef_pose, gripper_transformed)
+    
     def filter_grasps(self, grasp_poses):
         is_success_filtered = False
-        for grasp_pose, tcp_pose, contact_point, normal in grasp_poses:
+        for grasp_pose, _ in grasp_poses:
             qpos = self._compute_inverse_kinematics(grasp_pose)
             if qpos is None:
                 continue
@@ -116,10 +114,10 @@ class GraspManager(ActivityBase):
 
         if not is_success_filtered:
             logger.error(f"Failed to filter grasp poses")
-            return None, None, None, None
+            return None
         logger.info(f"Success to get grasp pose.\n")
 
-        return grasp_pose, tcp_pose, contact_point, normal
+        return grasp_pose
 
     def generate_tcp_poses(
         self,
@@ -146,24 +144,6 @@ class GraspManager(ActivityBase):
 
             yield (tcp_pose, contact_points, normals)
 
-    def get_grasp_waypoints(
-        self,
-        obj_mesh,
-        obj_pose,
-        limit_angle,
-        num_grasp=1,
-        n_trials=1,
-    ):
-        waypoints = OrderedDict()
-
-        grasp_pose, _, _, _= self.get_grasp_pose(obj_mesh, obj_pose, limit_angle, num_grasp, n_trials)
-        
-        waypoints["pre_grasp"] = self.pre_grasp_pose
-        waypoints["grasp"] = grasp_pose
-        waypoints["post_grasp"] =self.post_grasp_pose
-
-        return waypoints
-
     def get_release_waypoints(
         self,
         obj_mesh_on_sup,
@@ -176,7 +156,7 @@ class GraspManager(ActivityBase):
     ):
         waypoints = OrderedDict()
 
-        release_pose = self.get_support_pose(
+        release_pose = self.get_release_pose(
             obj_mesh_on_sup,
             obj_pose_on_sup,
             n_samples_on_sup,
@@ -191,7 +171,7 @@ class GraspManager(ActivityBase):
 
         return waypoints
         
-    def get_support_pose(
+    def get_release_pose(
         self,
         obj_mesh_on_sup,
         obj_pose_on_sup,
@@ -210,8 +190,7 @@ class GraspManager(ActivityBase):
             n_samples_for_sup,
             n_trials)
 
-        release_pose, result_obj_pose = self.filter_supports(support_poses)
-        self.result_obj_pose = result_obj_pose
+        release_pose = self.filter_supports(support_poses)
         return release_pose
 
     def get_pre_release_pose(self, release_pose):
@@ -238,8 +217,9 @@ class GraspManager(ActivityBase):
             support_points = self.sample_supports(obj_mesh_on_sup, obj_pose_on_sup, n_samples_on_sup,
                                             obj_mesh_for_sup, obj_pose_for_sup, n_samples_for_sup)
             
-            for result_obj_pose, obj_pose_transformed_for_sup, point_on_sup, point_transformed in self.transform_points_on_support(support_points, obj_pose_for_sup):
+            for result_obj_pose, obj_pose_transformed_for_sup, point_on_sup, point_transformed in self._transform_points_on_support(support_points, obj_pose_for_sup):
                 T = np.dot(obj_pose_for_sup, np.linalg.inv(obj_pose_transformed_for_sup))
+                self.obj_pose_transformed_for_sup = obj_pose_transformed_for_sup
                 gripper_pose_transformed = np.dot(T, self.tcp_pose)
                 result_gripper_pose = np.eye(4)
                 result_gripper_pose[:3, :3] = gripper_pose_transformed[:3, :3]
@@ -247,7 +227,8 @@ class GraspManager(ActivityBase):
 
                 gripper_transformed = self.get_gripper_transformed(result_gripper_pose)
                 if self.collision_free(gripper_transformed, only_gripper=True):
-                    yield result_obj_pose, gripper_transformed
+                    release_pose = gripper_transformed[self.robot.eef_name]
+                    yield release_pose, result_obj_pose
             cnt += 1
 
     def sample_supports(
@@ -266,7 +247,7 @@ class GraspManager(ActivityBase):
             for point_for_support, normal_for_support in sample_points_for_support:
                 yield point_on_support, normal_on_support, point_for_support, normal_for_support
 
-    def transform_points_on_support(self, support_points, obj_pose_for_sup):
+    def _transform_points_on_support(self, support_points, obj_pose_for_sup):
         for point_on_sup, normal_on_sup, point_for_sup, normal_for_sup in support_points:
             normal_on_sup = -normal_on_sup
             R_mat = get_rotation_from_vectors(normal_for_sup, normal_on_sup)
@@ -286,11 +267,10 @@ class GraspManager(ActivityBase):
 
     def filter_supports(self, support_poses):
         is_success_filtered = False
-        for result_obj_pose, gripper_transformed in support_poses:
+        for release_pose, result_obj_pose in support_poses:
             if not self._check_support(result_obj_pose):
                 continue
 
-            release_pose = gripper_transformed[self.robot.eef_name]
             qpos = self._compute_inverse_kinematics(release_pose)
             if qpos is None:
                 continue
@@ -307,15 +287,16 @@ class GraspManager(ActivityBase):
                 if self._check_ik_solution(pre_release_pose, pre_goal_pose) and self.collision_free(pre_transforms):
                     self.pre_release_pose = pre_release_pose
                     self.post_release_pose = pre_release_pose
+                    self.result_obj_pose = result_obj_pose
                     is_success_filtered = True
                     break
 
         if not is_success_filtered:
             logger.error(f"Failed to filter release poses")
-            return None, None, None, None
+            return None
         
         logger.info(f"Success to get release pose.\n")
-        return release_pose, result_obj_pose
+        return release_pose
 
     def generate_points_on_support(
         self,
@@ -332,8 +313,8 @@ class GraspManager(ActivityBase):
             if np.all(vertex[:,2] >= copied_mesh.bounds[1][2] * 0.98):                
                 weights[idx] = 1.0
 
-        place_points, face_ind, normal_vectors = surface_sampling(copied_mesh, n_samples, weights)
-        for point, normal_vector in zip(place_points, normal_vectors):
+        support_points, face_ind, normal_vectors = surface_sampling(copied_mesh, n_samples, weights)
+        for point, normal_vector in zip(support_points, normal_vectors):
             yield point, normal_vector
 
     def generate_points_for_support(
@@ -347,12 +328,12 @@ class GraspManager(ActivityBase):
     
         weights = np.zeros(len(copied_mesh.faces))
         for idx, vertex in enumerate(copied_mesh.vertices[copied_mesh.faces]):
-            weights[idx]=0.1
+            weights[idx]=0.3
             if np.all(vertex[:,2] <= copied_mesh.bounds[0][2] * 1.02):                
-                weights[idx] = 0.9
+                weights[idx] = 0.7
   
-        place_points, face_ind, normal_vectors = surface_sampling(copied_mesh, n_samples, weights)
-        for point, normal_vector in zip(place_points, normal_vectors):
+        support_points, face_ind, normal_vectors = surface_sampling(copied_mesh, n_samples, weights)
+        for point, normal_vector in zip(support_points, normal_vectors):
             yield point, normal_vector
 
     def _compute_inverse_kinematics(self, grasp_pose):
